Member functions
::::::::::::::::::::::::::::

.. toctree::
   :maxdepth: 3

   objects_and_functions.rst
   print.rst
   implicit_variable_access.rst
   another_example.rst
   yet_another_example.rst
   a_more_complicated_example.rst
   constructors.rst
   initialize_or_construct.rst
   one_last_example.rst
   header_files.rst
   glossary.rst
   Exercises.rst
   mixedUpCode.rst
   coding_practice.rst
